import{C as p,_ as n}from"./View.vue_vue_type_script_setup_true_lang-C4BzglYY.js";import{a as i,ac as s,p as a,e as m,u as c}from"./jwt-decode.esm-v5CEvqyh.js";import"./router-DgDq_IpX.js";import"./ts.worker-DA77weYC.js";import"./fetch-CmoNDn_0.js";import"./record-CDeTCon0.js";import"./SaveButton-REGDRqR9.js";import"./ExclamationCircleOutlined-sKK4IpLH.js";import"./CrudView-CIYYnFiP.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-DcVPsYZe.js";import"./constants-C0rOrpBl.js";import"./url-CZozyO9m.js";import"./PhDotsThreeVertical.vue-C4BypmgE.js";import"./index-D3GPnck7.js";import"./asyncComputed-Cg8EBPA1.js";import"./omniChatStore-DYVD1DOj.js";import"./uuid-B56xjvEo.js";import"./PhCopySimple.vue-C4niyB7a.js";import"./PhPencil.vue-CQwOz1vj.js";import"./useCodebaseEvents-CtijVEYs.js";import"./contracts.generated-CqI9knps.js";import"./index-B8TAzK6N.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="230ca48c-a644-4640-8542-45412115e5ee",o._sentryDebugIdIdentifier="sentry-dbid-230ca48c-a644-4640-8542-45412115e5ee")}catch{}})();const A=i({__name:"EnvVars",setup(o){const r=s().params.projectId,t=new p(r);return(d,u)=>(m(),a(n,{"env-var-repository":c(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars-Ds-Iiua0.js.map
