const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-BzsO9aPV.js","assets/workspaceStore-BqCiBLss.js","assets/jwt-decode.esm-v5CEvqyh.js","assets/jwt-decode-D9e-DIPp.css","assets/userStore-BvcSBmtw.js","assets/url-CZozyO9m.js","assets/colorHelpers-CZU0pTOo.js","assets/OidcLogoutCallback-DWt7OGGL.js","assets/Login-DPTEmKBg.js","assets/Login.vue_vue_type_script_setup_true_lang-CymCH-1n.js","assets/OTPInput-D83Ce84L.js","assets/OTPInput-C8ldH5jb.css","assets/Logo-B_5etFZi.js","assets/Logo-D2kepPyK.css","assets/string--RMs17yr.js","assets/CircularLoading-BValBQE9.js","assets/CircularLoading-BiyobKo3.css","assets/index-B8TAzK6N.js","assets/Login-cMuNqCbG.css","assets/Login-C1k-SC0u.css","assets/Main-PIl1mxUs.js","assets/PlayerNavbar-DYwn4TBM.js","assets/metadata-F2K_ZUMP.js","assets/PhMagnifyingGlass.vue-3GYo7lOF.js","assets/PhWebhooksLogo.vue-7cBkNeeE.js","assets/LoadingOutlined-gWCis-gC.js","assets/PhSignOut.vue-1tU8CkBV.js","assets/index-DCo-zwjI.js","assets/PlayerNavbar-VlEtzX8f.css","assets/Main-DqPmGmnC.css","assets/Home-CB7tESKD.js","assets/Watermark-DDvUDwmE.js","assets/constants-C0rOrpBl.js","assets/Watermark-DMbnzHiR.css","assets/PhArrowSquareOut.vue-Bf-gzMsI.js","assets/index-DZcDM0Jg.js","assets/Home-B6UGln4L.css","assets/Error-752aEoAQ.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-CnZPmRcz.js","assets/Error-CIbhyrKS.css","assets/Form-BEBSnZXc.js","assets/FormRunner-CD75PeyM.js","assets/Steps-CmBSxfTQ.js","assets/index-CdWTNMD0.js","assets/Steps-DqO_G9S3.css","assets/FormRunner-61-wByB6.css","assets/redirect-ftoDeM3R.js","assets/asyncComputed-Cg8EBPA1.js","assets/uuid-B56xjvEo.js","assets/Form-A1oa-Q46.css"])))=>i.map(i=>d[i]);
import{ag as s,ah as d,ad as t,ai as m}from"./jwt-decode.esm-v5CEvqyh.js";import{a as u}from"./workspaceStore-BqCiBLss.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="84b6f0ef-9ae5-403c-aa78-794b41c0c18f",e._sentryDebugIdIdentifier="sentry-dbid-84b6f0ef-9ae5-403c-aa78-794b41c0c18f")}catch{}})();const b=async()=>{try{const e=await fetch("/_editor/api/workspace/version");return e.ok&&(await e.json()).version||"658490578a3fe990c2a0569cc2de62f4d726978c"}catch(e){return console.error("Failed to fetch Abstra version:",e),"658490578a3fe990c2a0569cc2de62f4d726978c"}},p=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-BzsO9aPV.js"),__vite__mapDeps([0,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-DWt7OGGL.js"),__vite__mapDeps([7,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-DPTEmKBg.js"),__vite__mapDeps([8,9,2,3,1,4,5,6,10,11,12,13,14,15,16,17,18,19])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-PIl1mxUs.js"),__vite__mapDeps([20,21,4,2,3,1,5,6,22,23,24,25,26,27,28,29])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-CB7tESKD.js"),__vite__mapDeps([30,22,2,3,23,24,31,1,4,5,6,32,33,34,35,25,36])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-752aEoAQ.js"),__vite__mapDeps([37,38,12,2,3,13,32,1,4,5,6,35,39])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-BEBSnZXc.js"),__vite__mapDeps([40,4,2,3,41,9,1,5,6,10,11,12,13,14,15,16,17,18,42,43,44,31,32,33,45,46,47,48,49])),meta:{hideLogin:!0}}]}],o=s({history:d("/"),routes:p,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),l=e=>async(a,r)=>{if(m(a,r),a.meta.allowUnauthenticated)return;const n=await u(a.path),{redirect:c,...i}=a.query;switch(n.status){case"ALLOWED":break;case"UNAUTHORIZED":await e.push({name:"playerLogin",query:{...i,redirect:c||a.path},params:a.params});break;case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};o.beforeEach(l(o));export{p as a,l as b,b as g,o as r};
//# sourceMappingURL=router-C3T_cLCa.js.map
